@@ -37,7 +37,7 @@ def static_url(file_path):
 def url(addr, *args, **kwargs):
     for route in router.routes:
         if ':' in addr:
-            print(addr)
+            # print(addr)
             *_, ap, ur = addr.split(':')
             addr = f'{ur}_{ap}'
         if route.name == addr:
